@@ -392,19 +392,31 @@ static char *readAddress(const char *configFile, int lineNum, const char *key,
 
 static int do_mkdir(const char *path, mode_t mode, uid_t uid, gid_t gid) {
     if (mkdir(path, mode) == 0) {
+        int fd;
+
         /* newly created directory, set the owner and permissions */
-        if (chown(path, uid, gid) != 0) {
+        fd = open(path, O_RDONLY | O_DIRECTORY | O_NOFOLLOW);
+        if (fd < 0) {
+            message(MESS_ERROR, "error opening %s after creation: %s\n",
+                    path, strerror(errno));
+            return -1;
+        }
+
+        if (fchown(fd, uid, gid) != 0) {
             message(MESS_ERROR, "error setting owner of %s to uid %u and gid %u: %s\n",
                     path, (unsigned) uid, (unsigned) gid, strerror(errno));
+            close(fd);
             return -1;
         }
 
-        if (chmod(path, mode) != 0) {
+        if (fchmod(fd, mode) != 0) {
             message(MESS_ERROR, "error setting permissions of %s to 0%o: %s\n",
                     path, mode, strerror(errno));
+            close(fd);
             return -1;
         }
 
+        close(fd);
         return 0;
     }
 
@@ -943,7 +955,7 @@ static int globerr(const char *pathname, int theerr)
         } else { \
             goto error; \
         } \
-    } while(0)
+    } while (0)
 #define MAX_NESTING 16U
 
 static int readConfigFile(const char *configFile, struct logInfo *defConfig)
@@ -956,7 +968,7 @@ static int readConfigFile(const char *configFile, struct logInfo *defConfig)
     char **scriptDest = NULL;
     struct logInfo *newlog = defConfig;
     char *start, *chptr;
-    struct stat sb;
+    struct stat sb_config;
     int state = STATE_DEFAULT;
     int logerror = 0;
     /* to check if incompatible criteria are specified */
@@ -986,13 +998,13 @@ static int readConfigFile(const char *configFile, struct logInfo *defConfig)
         message(MESS_ERROR, "Could not lock file %s for reading\n",
                 configFile);
     }
-    if (fstat(fd, &sb)) {
+    if (fstat(fd, &sb_config)) {
         message(MESS_ERROR, "fstat of %s failed: %s\n", configFile,
                 strerror(errno));
         close(fd);
         return 1;
     }
-    if (!S_ISREG(sb.st_mode)) {
+    if (!S_ISREG(sb_config.st_mode)) {
         message(MESS_DEBUG,
                 "Ignoring %s because it's not a regular file.\n",
                 configFile);
@@ -1008,13 +1020,13 @@ static int readConfigFile(const char *configFile, struct logInfo *defConfig)
     }
 
     if (getuid() == ROOT_UID) {
-        if ((sb.st_mode & 07533) != 0400) {
+        if ((sb_config.st_mode & 07533) != 0400) {
             message(MESS_NORMAL,
                     "Potentially dangerous mode on %s: 0%o\n",
-                    configFile, (unsigned) (sb.st_mode & 07777));
+                    configFile, (unsigned) (sb_config.st_mode & 07777));
         }
 
-        if (sb.st_mode & 0022) {
+        if (sb_config.st_mode & 0022) {
             message(MESS_ERROR,
                     "Ignoring %s because it is writable by group or others.\n",
                     configFile);
@@ -1022,7 +1034,7 @@ static int readConfigFile(const char *configFile, struct logInfo *defConfig)
             return 0;
         }
 
-        if (sb.st_uid != ROOT_UID) {
+        if (sb_config.st_uid != ROOT_UID) {
             message(MESS_ERROR,
                     "Ignoring %s because the file owner is wrong (should be root or user with uid 0).\n",
                     configFile);
@@ -1031,7 +1043,7 @@ static int readConfigFile(const char *configFile, struct logInfo *defConfig)
         }
     }
 
-    length = (size_t)sb.st_size;
+    length = (size_t)sb_config.st_size;
 
     if (length > 0xffffff) {
         message(MESS_ERROR, "file %s too large, probably not a config file.\n",
@@ -1095,12 +1107,13 @@ static int readConfigFile(const char *configFile, struct logInfo *defConfig)
                     if (key == NULL) {
                         message(MESS_ERROR, "%s:%d failed to parse keyword\n",
                                 configFile, lineNum);
-                        continue;
+                        RAISE_ERROR();
                     }
-                    if (!isspace((unsigned char)*start)) {
-                        message(MESS_NORMAL, "%s:%d keyword '%s' not properly"
+                    if (!isspace((unsigned char)*start) && *start != '=') {
+                        message(MESS_ERROR, "%s:%d keyword '%s' not properly"
                                 " separated, found %#x\n",
                                 configFile, lineNum, key, *start);
+                        RAISE_ERROR();
                     }
                     if (!strcmp(key, "compress")) {
                         newlog->flags |= LOG_FLAG_COMPRESS;
@@ -1114,6 +1127,10 @@ static int readConfigFile(const char *configFile, struct logInfo *defConfig)
                         newlog->flags |= LOG_FLAG_SHRED;
                     } else if (!strcmp(key, "noshred")) {
                         newlog->flags &= ~LOG_FLAG_SHRED;
+                    } else if (!strcmp(key, "allowhardlink")) {
+                        newlog->flags |= LOG_FLAG_ALLOWHARDLINK;
+                    } else if (!strcmp(key, "noallowhardlink")) {
+                        newlog->flags &= ~LOG_FLAG_ALLOWHARDLINK;
                     } else if (!strcmp(key, "sharedscripts")) {
                         newlog->flags |= LOG_FLAG_SHAREDSCRIPTS;
                     } else if (!strcmp(key, "nosharedscripts")) {
@@ -1643,7 +1660,7 @@ static int readConfigFile(const char *configFile, struct logInfo *defConfig)
 
                         /* we check whether we changed the compress_cmd. In case we use the appropriate extension
                            as listed in compress_cmd_list */
-                        for(i = 0; i < compress_cmd_list_size; i++) {
+                        for (i = 0; i < compress_cmd_list_size; i++) {
                             if (!strcmp(compress_cmd_list[i].cmd, compresscmd_base)) {
                                 freeLogItem (compress_ext);
                                 newlog->compress_ext = strdup(compress_cmd_list[i].ext);
@@ -1816,10 +1833,11 @@ static int readConfigFile(const char *configFile, struct logInfo *defConfig)
 
                         for (glob_count = 0; glob_count < globResult.gl_pathc; glob_count++) {
                             struct logInfo *log;
+                            struct stat sb_glob;
 
                             /* if we glob directories we can get false matches */
-                            if (!lstat(globResult.gl_pathv[glob_count], &sb) &&
-                                    S_ISDIR(sb.st_mode)) {
+                            if (!lstat(globResult.gl_pathv[glob_count], &sb_glob) &&
+                                    S_ISDIR(sb_glob.st_mode)) {
                                 continue;
                             }
 
@@ -1883,7 +1901,8 @@ duperror:
                             char *ld;
                             char *dirpath;
                             const char *dirName;
-                            struct stat sb2;
+                            struct stat sb_logdir;
+                            struct stat sb_olddir;
 
                             dirpath = strdup(newlog->files[j]);
                             if (dirpath == NULL) {
@@ -1892,7 +1911,7 @@ duperror:
                             }
 
                             dirName = dirname(dirpath);
-                            if (stat(dirName, &sb2)) {
+                            if (stat(dirName, &sb_logdir)) {
                                 if (!(newlog->flags & LOG_FLAG_MISSINGOK)) {
                                     message(MESS_ERROR,
                                             "%s:%d error verifying log file "
@@ -1927,7 +1946,7 @@ duperror:
                                 dirName = newlog->oldDir;
                             }
 
-                            if (stat(dirName, &sb)) {
+                            if (stat(dirName, &sb_olddir)) {
                                 if (errno == ENOENT && (newlog->flags & LOG_FLAG_OLDDIRCREATE)) {
                                     int ret;
                                     if (newlog->flags & LOG_FLAG_SU) {
@@ -1948,6 +1967,14 @@ duperror:
                                         free(ld);
                                         goto error;
                                     }
+
+                                    if (stat(dirName, &sb_olddir) != 0) {
+                                        message(MESS_ERROR, "%s:%d error verifying created olddir "
+                                                "path %s: %s\n", configFile, lineNum,
+                                                dirName, strerror(errno));
+                                        free(ld);
+                                        goto error;
+                                    }
                                 }
                                 else {
                                     message(MESS_ERROR, "%s:%d error verifying olddir "
@@ -1960,7 +1987,7 @@ duperror:
 
                             free(ld);
 
-                            if (sb.st_dev != sb2.st_dev
+                            if (sb_logdir.st_dev != sb_olddir.st_dev
                                     && !(newlog->flags & (LOG_FLAG_COPYTRUNCATE | LOG_FLAG_COPY | LOG_FLAG_TMPFILENAME))) {
                                 message(MESS_ERROR,
                                         "%s:%d olddir %s and log file %s "
@@ -1978,7 +2005,7 @@ duperror:
                     message(MESS_ERROR, "%s:%d lines must begin with a keyword "
                             "or a filename (possibly in double quotes)\n",
                             configFile, lineNum);
-                    state = STATE_SKIP_LINE;
+                    RAISE_ERROR();
                 }
                 break;
             case STATE_SKIP_LINE:
@@ -2115,6 +2142,8 @@ next_state: ;
     free(globerr_msg);
     return logerror;
 error:
+    if (newlog != defConfig)
+        freeTailLogs(1);
     /* free is a NULL-safe operation */
     free(key);
     munmap(buf, length);
