@@ -11,7 +11,7 @@ preptest test.log 64 1 0
 
 DATESTRING=$(/bin/date +%Y%m%d)
 
-$RLR test-config.64 --force
+$RLR test-config.64 --force || exit 23
 checkoutput <<EOF
 test.log 0
 EOF
